@@ -2,7 +2,7 @@ from unittest import TestSuite
 
 import test_doctests, test_prepared, test_equality, test_geomseq, test_xy
 import test_collection, test_emptiness, test_singularity, test_validation
-import test_mapping
+import test_mapping, test_delegated, test_dlls
 
 def test_suite():
     suite = TestSuite()
@@ -16,5 +16,7 @@ def test_suite():
     suite.addTest(test_singularity.test_suite())
     suite.addTest(test_validation.test_suite())
     suite.addTest(test_mapping.test_suite())
+    suite.addTest(test_delegated.test_suite())
+    suite.addTest(test_dlls.test_suite())
     return suite
 
